@@ -7,7 +7,7 @@ use warnings;
 use Moo;
 use namespace::autoclean;
 
-our $VERSION = '0.044'; # VERSION
+our $VERSION = '0.045'; # VERSION
 our $AUTHORITY = 'cpan:IMAGO'; # AUTHORITY
 
 with 'Regru::API::Role::Client';
@@ -25,6 +25,7 @@ sub available_methods {[qw(
     add_ns
     add_txt
     add_srv
+    add_spf
     get_resource_records
     update_records
     update_soa
@@ -53,7 +54,7 @@ Regru::API::Zone - REG.API v2 DNS resource records management
 
 =head1 VERSION
 
-version 0.044
+version 0.045
 
 =head1 DESCRIPTION
 
@@ -208,6 +209,22 @@ error otherwise.
 
 More info at L<DNS management: add_srv|https://www.reg.com/support/help/api2#zone_add_srv>.
 
+=head2 add_spf
+
+Creates a SPF (sender policy framework) resource record up to 512 characters in length.
+Scope: B<clients>. Typical usage:
+
+    $resp = $client->zone->add_spf(
+        subdomain   => '@',
+        domain_name => 'stand-poor.net',
+        text        => 'v=spf1 include:_spf.google.com ~all',
+    );
+
+Answer will contains a field C<domains> with a list of results for each involved to this operation domain names or
+error otherwise.
+
+More info at L<DNS management: add_spf|https://www.reg.com/support/help/api2#zone_add_spf>.
+
 =head2 get_resource_records
 
 Retrieves all resource records for domain(s). Scope: B<clients>. Typical usage:
